======================
agate-charts |release|
======================

.. include:: ../README.rst

Why agate-charts?
=================

* A clean, readable API.
* Automatically infers good defaults from your data.
* Far simpler than using matplotlib directly.
* Code, chart, code, chart. No context switching.
* It makes this with one line of code:

.. image:: samples/line_chart_complex_multiples.png

Install
=======

To install:

.. code-block:: bash

    pip install agate-charts

For details on development or supported platforms see the `agate documentation <https://agate.readthedocs.org>`_.

Table of contents
=================

.. toctree::
    :maxdepth: 2

    tutorial
    samples
    api

Authors
=======

.. include:: ../AUTHORS.rst

Changelog
=========

.. include:: ../CHANGELOG.rst

License
=======

.. include:: ../COPYING

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
